capitalization_iterator

Function capitalization_iterator 

pub(crate) fn capitalization_iterator(
    input_iterator: impl Iterator<Item = CharacterTransformIteration>,
    size_hint: usize,
    allow_word_at_start: bool,
) -> impl Iterator<Item = CharacterTransformIteration>
Given an input iterator, a size hint for the number items in the iterator, and a boolean determining whether the start of the input represents a word boundary, return an iterator that capitalizes one-to-one mapped characters from the input iterator.