is_typographic_letter_unit

Function is_typographic_letter_unit 

fn is_typographic_letter_unit(character: char) -> bool
From https://drafts.csswg.org/css-text-4/#typographic-letter-unit:

A typographic letter unit (or letter for the purpose of this specification) is a typographic character unit belonging to one of the Letter or Number general categories. See Appendix E: Characters and Properties for how to determine the Unicode properties of a typographic character unit.