map_character_for_webkit_text_security

Function map_character_for_webkit_text_security 

fn map_character_for_webkit_text_security(mode: T, character: char) -> char
Map a character according to the rules of the -webkit-text-security CSS property.

Note: The behavior of -webkit-text-security isn’t specified, so we have some flexibility in the implementation. We just need to maintain a rough compatibility with other browsers.