fn is_typographic_letter_unit(character: char) -> boolExpand description
From https://drafts.csswg.org/css-text-4/#typographic-letter-unit:
A typographic letter unit (or letter for the purpose of this specification) is a typographic character unit belonging to one of the Letter or Number general categories. See Appendix E: Characters and Properties for how to determine the Unicode properties of a typographic character unit.